#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 finite-typelits
version:              0.1.4.2
visibility:           public
id:                   finite-typelits-0.1.4.2-7qYBFGRPBrxJJWOeOEWRxW
key:                  finite-typelits-0.1.4.2-7qYBFGRPBrxJJWOeOEWRxW
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals.

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  b2063fde6e86f0458872adab06439af4
exposed:              True
exposed-modules:      Data.Finite Data.Finite.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/finite-typelits-0.1.4.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/finite-typelits-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/finite-typelits-0.1.4.2
hs-libraries:         HSfinite-typelits-0.1.4.2-7qYBFGRPBrxJJWOeOEWRxW
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

